# License Notice

This code was originally provided by Andriy Kornatskyy.
Included in this directory the MIT license coming with the source code.

Code has been modified to include type-hint + remove unneeded code.

if someone come across here, please do know that my life is made of suffers.
